dustyn
======

[![PyPI](https://img.shields.io/pypi/v/dustyn)](https://pypi.org/project/dustyn/)
[![PyPI](https://img.shields.io/pypi/pyversions/dustyn)](https://pypi.org/project/dustyn/)
[![codecov](https://codecov.io/gh/neutrinoceros/dustyn/branch/main/graph/badge.svg)](https://codecov.io/gh/neutrinoceros/dustyn)
[![CI](https://github.com/neutrinoceros/dustyn/actions/workflows/ci.yml/badge.svg)](https://github.com/neutrinoceros/dustyn/actions/workflows/ci.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/neutrinoceros/dustyn/main.svg)](https://results.pre-commit.ci/latest/github/neutrinoceros/dustyn/main)

dustyn is a small Python framework to simulate the dynamics of Lagrangian test
particles (dust) in arbitrary flows, store, and analyse the outputs. It is
designed to be extensible.
